@@ -342,12 +342,25 @@ my @tests = (
         }
     },
     {
-        # Debian 
+        # Debian
         name => 'jellyfish',
         verify_annotation => {
             'binary:libjellyfish-perl' => $jellyfish_annotation,
             'source Source' => " Dummy source comment\n that should be preserved when writing file backend",
         }
+    },
+    {
+        name => 'libburn-with-autoreconf',
+        check_before_fix => {
+            log4perl_dump_warnings => [ ],
+        },
+        apply_fix => 1,
+        check => {
+            'source Build-Depends:0' => undef,
+            'source Build-Depends:1' => 'pkg-config',
+            'source Build-Depends:2' => 'debhelper-compat (= 12)',
+            'source Build-Depends:3' => qr/libcam-dev/,
+        }
     }
 );
 
